@@ -15,7 +15,7 @@ Readonly::Array our @ABSOLUTE_LENGTHS => qw(cm mm in px pt pc);
 Readonly::Array our @RELATIVE_LENGTHS => qw(em ex ch rem vw vh vmin vmax %);
 Readonly::Array our @COLOR_FUNC => qw(rgb rgba hsl hsla);
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 sub check_array_css_color {
 	my ($self, $key) = @_;
@@ -66,16 +66,22 @@ sub check_css_unit {
 
 	_check_key($self, $key) && return;
 
-	my ($num, $unit) = $self->{$key} =~ m/^(\d+)([^\d]*)$/ms;
+	my $value = $self->{$key};
+	my ($num, $unit) = $value =~ m/^(\d+)([^\d]*)$/ms;
 	if (! $num) {
-		err "Parameter '$key' doesn't contain number.";
+		err "Parameter '$key' doesn't contain number.",
+			'Value', $value,
+		;
 	}
 	if (! $unit) {
-		err "Parameter '$key' doesn't contain unit.";
+		err "Parameter '$key' doesn't contain unit.",
+			'Value', $value,
+		;
 	}
 	if (none { $_ eq $unit } (@ABSOLUTE_LENGTHS, @RELATIVE_LENGTHS)) {
 		err "Parameter '$key' contain bad unit.",
-			'Value', $unit,
+			'Unit', $unit,
+			'Value', $value,
 		;
 	}
 
@@ -260,6 +266,8 @@ Mo utilities for checking of CSS style things.
 
  check_array_css_color($self, $key);
 
+I<Since version 0.03.>
+
 Check parameter defined by C<$key> which is reference to array.
 Check if all values are CSS colors.
 
@@ -271,6 +279,8 @@ Returns undef.
 
  check_css_class($self, $key);
 
+I<Since version 0.02.>
+
 Check parameter defined by C<$key> if it's CSS class name.
 Value could be undefined.
 
@@ -282,6 +292,8 @@ Returns undef.
 
  check_css_color($self, $key);
 
+I<Since version 0.03.>
+
 Check parameter defined by C<$key> if it's CSS color.
 Value could be undefined.
 
@@ -293,6 +305,8 @@ Returns undef.
 
  check_css_unit($self, $key);
 
+I<Since version 0.01. Described functionality since version 0.04.>
+
 Check parameter defined by C<$key> if it's CSS unit.
 Value could be undefined.
 
@@ -329,8 +343,11 @@ Returns undef.
 
  check_css_unit():
          Parameter '%s' doesn't contain number.
+                 Value: %s
          Parameter '%s' doesn't contain unit.
+                 Value: %s
          Parameter '%s' contain bad unit.
+                 Unit: %s
                  Value: %s
 
 =head1 EXAMPLE1
@@ -559,6 +576,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
